@@ -8,6 +8,8 @@ from bxcommon.messages.bloxroute.v7.bloxroute_message_factory_v7 import bloxrout
 from bxcommon.messages.bloxroute.v7.message_converter_factory_v7 import message_converter_factory_v7
 from bxcommon.messages.bloxroute.v8.bloxroute_message_factory_v8 import bloxroute_message_factory_v8
 from bxcommon.messages.bloxroute.v8.message_converter_factory_v8 import message_converter_factory_v8
+from bxcommon.messages.bloxroute.v9.bloxroute_message_factory_v9 import bloxroute_message_factory_v9
+from bxcommon.messages.bloxroute.v9.message_converter_factory_v9 import message_converter_factory_v9
 from bxcommon.messages.versioning.abstract_version_manager import AbstractVersionManager
 
 
@@ -19,12 +21,14 @@ class _BloxrouteVersionManager(AbstractVersionManager):
         6: message_converter_factory_v6,
         7: message_converter_factory_v7,
         8: message_converter_factory_v8,
+        9: message_converter_factory_v9,
     }
     _PROTOCOL_TO_FACTORY_MAPPING = {
         6: bloxroute_message_factory_v6,
         7: bloxroute_message_factory_v7,
         8: bloxroute_message_factory_v8,
-        9: bloxroute_message_factory,
+        9: bloxroute_message_factory_v9,
+        10: bloxroute_message_factory,
     }
 
     def __init__(self):
