@@ -3,8 +3,11 @@ from bxcommon.messages.validation.message_validation_error import MessageValidat
 
 
 class ControlFlagValidationError(MessageValidationError):
-    # pyre-fixme[9]: control_flag_byte has type `int`; used as `None`.
-    def __init__(self, msg: str, control_flag_byte: int = None):
-        super(ControlFlagValidationError, self).__init__(msg)
-        self.is_cancelled_cut_through = BloxrouteMessageControlFlags.NONE is BloxrouteMessageControlFlags(control_flag_byte)
+    is_cancelled_cut_through: bool
 
+    def __init__(self, msg: str, control_flag_byte: int):
+        super(ControlFlagValidationError, self).__init__(msg)
+        if BloxrouteMessageControlFlags(control_flag_byte) is BloxrouteMessageControlFlags.NONE:
+            self.is_cancelled_cut_through = True
+        else:
+            self.is_cancelled_cut_through = False
