@@ -145,22 +145,22 @@ class ExtensionTransactionService(TransactionService):
 
     def process_gateway_transaction_from_bdn(
         self,
-        tx_hash: Sha256Hash,
+        transaction_hash: Sha256Hash,
         short_id: int,
-        tx_contents: Union[bytearray, memoryview],
+        transaction_contents: Union[bytearray, memoryview],
         is_compact: bool
     ) -> TransactionFromBdnGatewayProcessingResult:
 
-        transaction_cache_key = self._tx_hash_to_cache_key(tx_hash)
+        transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
 
         ext_result = self.proxy.process_gateway_transaction_from_bdn(
             transaction_cache_key,
-            tpe.InputBytes(tx_contents),
+            tpe.InputBytes(transaction_contents),
             short_id,
             is_compact
         )
 
-        return TransactionFromBdnGatewayProcessingResult(
+        result = TransactionFromBdnGatewayProcessingResult(
             ext_result.get_ignore_seen(),
             ext_result.get_existing_short_id(),
             ext_result.get_assigned_short_id(),
@@ -168,6 +168,29 @@ class ExtensionTransactionService(TransactionService):
             ext_result.get_set_contents()
         )
 
+        if result.set_content:
+            has_short_id, previous_size = ext_result.get_set_contents_result()
+            self.set_transaction_contents_base(
+                transaction_hash,
+                transaction_cache_key,
+                transaction_contents,
+                has_short_id,
+                previous_size,
+                False
+            )
+
+        if result.assigned_short_id:
+            has_contents = result.existing_contents or result.set_content
+            self.assign_short_id_base(
+                transaction_hash,
+                transaction_cache_key,
+                short_id,
+                has_contents,
+                False
+            )
+
+        return result
+
     def log_tx_service_mem_stats(self):
         super(ExtensionTransactionService, self).log_tx_service_mem_stats()
         if self.node.opts.stats_calculate_actual_size:
