@@ -13,11 +13,9 @@ from typing import List, Tuple, Generator, Optional, Union, Dict, Set, Any, Iter
 from prometheus_client import Gauge
 
 from bxcommon import constants
-from bxcommon.messages.bloxroute.tx_message import TxMessage
 from bxcommon.models.quota_type_model import QuotaType
 from bxcommon.models.transaction_info import TransactionSearchResult, TransactionInfo
 from bxcommon.utils import memory_utils, convert
-from bxcommon.utils import performance_utils
 from bxcommon.utils.crypto import SHA256_HASH_LEN
 from bxcommon.utils.expiration_queue import ExpirationQueue
 from bxcommon.utils.memory_utils import ObjectSize
@@ -377,17 +375,6 @@ class TransactionService:
         """
         return cache_key in self._tx_hash_to_time_removed
 
-    def process_bx_tx_messages(
-        self, bx_tx_messages: List[Tuple[TxMessage, Sha256Hash, Union[bytearray, memoryview]]]
-    ) -> Iterator[Tuple[TxMessage, Sha256Hash, Any, Union[bytearray, memoryview], bool]]:
-
-        for bx_tx_message, tx_hash, tx_bytes in bx_tx_messages:
-            tx_cache_key = self._tx_hash_to_cache_key(tx_hash)
-            tx_seen_flag = self.has_transaction_contents_by_cache_key(tx_cache_key) or \
-                           self.removed_transaction_by_cache_key(tx_cache_key)
-
-            yield bx_tx_message, tx_hash, tx_cache_key, tx_bytes, tx_seen_flag
-
     def remove_sid_by_tx_hash(self, transaction_hash: Sha256Hash):
         transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
         if transaction_cache_key in self._tx_cache_key_to_contents:
@@ -872,17 +859,17 @@ class TransactionService:
 
     def process_gateway_transaction_from_bdn(
         self,
-        tx_hash: Sha256Hash,
+        transaction_hash: Sha256Hash,
         short_id: int,
-        tx_contents: Union[bytearray, memoryview],
+        transaction_contents: Union[bytearray, memoryview],
         is_compact: bool) -> TransactionFromBdnGatewayProcessingResult:
 
-        if (not short_id and self.has_transaction_short_id(tx_hash) and self.has_transaction_contents(tx_hash)) or \
-            self.removed_transaction(tx_hash):
+        if (not short_id and self.has_transaction_short_id(transaction_hash) and
+            self.has_transaction_contents(transaction_hash)) or self.removed_transaction(transaction_hash):
             return TransactionFromBdnGatewayProcessingResult(ignore_seen=True)
 
-        existing_short_ids = self.get_short_ids(tx_hash)
-        if (self.has_transaction_contents(tx_hash) or is_compact) \
+        existing_short_ids = self.get_short_ids(transaction_hash)
+        if (self.has_transaction_contents(transaction_hash) or is_compact) \
             and short_id and short_id in existing_short_ids:
             return TransactionFromBdnGatewayProcessingResult(existing_short_id=True)
 
@@ -890,13 +877,13 @@ class TransactionService:
         set_content = False
 
         if short_id and short_id not in existing_short_ids:
-            self.assign_short_id(tx_hash, short_id)
+            self.assign_short_id(transaction_hash, short_id)
             assigned_short_id = True
 
-        existing_contents = self.has_transaction_contents(tx_hash)
+        existing_contents = self.has_transaction_contents(transaction_hash)
 
         if not is_compact and not existing_contents:
-            self.set_transaction_contents(tx_hash, tx_contents)
+            self.set_transaction_contents(transaction_hash, transaction_contents)
             set_content = True
 
         return TransactionFromBdnGatewayProcessingResult(
@@ -1174,7 +1161,7 @@ class TransactionService:
         """
         if self.node.opts.transaction_pool_memory_limit is not None:
             # convert MB to bytes
-            return self.node.opts.transaction_pool_memory_limit * 1024 * 1024
+            return int(self.node.opts.transaction_pool_memory_limit * 1024 * 1024)
 
         for blockchain_network in self.node.opts.blockchain_networks:
             if blockchain_network.network_num == self.network_num:
@@ -1312,18 +1299,3 @@ class TransactionService:
         )
 
         return constants.REMOVED_TRANSACTIONS_HISTORY_CLEANUP_INTERVAL_S
-
-    def set_transactions_contents(
-        self, pending_tx_to_set: List[Tuple[Sha256Hash, Union[memoryview, bytearray], str]]
-    ) -> None:
-        start = time.time()
-        for tx_hash, tx_bytes, tx_cache_key in pending_tx_to_set:
-            self.set_transaction_contents(tx_hash, tx_bytes, tx_cache_key)
-        performance_utils.log_operation_duration(
-            performance_logger,
-            "set_tx_content",
-            start,
-            constants.TX_SERVICE_SET_TXS_WARN_THRESHOLD,
-            tx_count=len(pending_tx_to_set),
-            duration=time.time() - start
-        )
