@@ -1,5 +1,7 @@
 import random
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast, Optional
+
+import rlp
 
 from bxcommon import constants
 from bxcommon.connections.connection_type import ConnectionType
@@ -14,10 +16,16 @@ from bxcommon.utils.stats.block_stat_event_type import BlockStatEventType
 from bxcommon.utils.stats.block_statistics_service import block_stats
 from bxgateway import gateway_constants
 from bxgateway import log_messages
+from bxgateway.feed.pending_transaction_feed import PendingTransactionFeed
+from bxgateway.feed.new_transaction_feed import TransactionFeedEntry
+from bxgateway.messages.eth.serializers.transaction import Transaction
+from bxgateway.messages.gateway.confirmed_tx_message import ConfirmedTxMessage
 from bxgateway.messages.gateway.gateway_hello_message import GatewayHelloMessage
 from bxgateway.messages.gateway.gateway_message_factory import gateway_message_factory
 from bxgateway.messages.gateway.gateway_message_type import GatewayMessageType
 from bxgateway.messages.gateway.gateway_version_manager import gateway_version_manager
+from bxgateway.messages.gateway.request_tx_stream_message import RequestTxStreamMessage
+from bxgateway.utils.stats.transaction_feed_stats_service import transaction_feed_stats_service
 
 if TYPE_CHECKING:
     from bxgateway.connections.abstract_gateway_node import AbstractGatewayNode
@@ -47,6 +55,8 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
             GatewayMessageType.BLOCK_PROPAGATION_REQUEST: self.msg_block_propagation_request,
             BloxrouteMessageType.BLOCK_HOLDING: self.msg_block_holding,
             BloxrouteMessageType.KEY: self.msg_key,
+            GatewayMessageType.CONFIRMED_TX: self.msg_confirmed_tx,
+            GatewayMessageType.REQUEST_TX_STREAM: self.msg_request_tx_stream,
         }
         self.version_manager = gateway_version_manager
         self.protocol_version = self.version_manager.CURRENT_PROTOCOL_VERSION
@@ -56,6 +66,17 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         else:
             self.ordering = self.NULL_ORDERING
 
+    def on_connection_established(self):
+        super().on_connection_established()
+
+        peer_model = self.peer_model
+        if (
+            self.node.opts.request_remote_transaction_streaming
+            and peer_model is not None
+            and peer_model.is_transaction_streamer()
+        ):
+            self.enqueue_msg(RequestTxStreamMessage())
+
     def msg_hello(self, msg):
         """
         Updates connection pool references to this connection to match the port described in the hello message.
@@ -169,6 +190,40 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         """
         self.node.block_processing_service.process_block_key(msg, self)
 
+    def msg_confirmed_tx(self, msg: ConfirmedTxMessage) -> None:
+        tx_hash = msg.tx_hash()
+        transaction_feed_stats_service.log_pending_transaction_from_internal(tx_hash)
+
+        if not self.node.feed_manager.any_subscribers():
+            self.node.feed_manager.keep_feed_alive(PendingTransactionFeed.NAME)
+            return
+
+        tx_contents = msg.tx_val()
+
+        # shouldn't ever happen, but just in case
+        if tx_contents == ConfirmedTxMessage.EMPTY_TX_VAL:
+            tx_contents = cast(
+                Optional[memoryview],
+                self.node.get_tx_service().get_transaction_by_hash(tx_hash)
+            )
+            if tx_contents is None:
+                transaction_feed_stats_service.log_pending_transaction_missing_contents()
+                return
+
+        try:
+            transaction = rlp.decode(tx_contents.tobytes(), Transaction)
+            self.node.feed_manager.publish_to_feed(
+                PendingTransactionFeed.NAME,
+                TransactionFeedEntry(tx_hash, transaction.to_json())
+            )
+        except Exception as e:
+            self.log_error(
+                log_messages.COULD_NOT_DESERIALIZE_TRANSACTION, tx_hash, e, exc_info=True
+            )
+
+    def msg_request_tx_stream(self, msg: RequestTxStreamMessage) -> None:
+        pass
+
     def _initialize_ordered_handshake(self):
         self.ordering = random.getrandbits(constants.UL_INT_SIZE_IN_BYTES * 8)
         self.enqueue_msg(GatewayHelloMessage(self.protocol_version, self.network_num, self.node.opts.external_ip,
