@@ -92,3 +92,7 @@ GATEWAY_PRIVATE_KEY_FILE_NAME = ".gatewaykey"
 BLOCK_CONFIRMATION_REQUEST_INTERVALS = 5
 BLOCK_CONFIRMATION_REQUEST_CACHE_INTERVAL_S = 30 * 60
 
+EIP155_CHAIN_ID_OFFSET = 35
+
+ETH_DEFAULT_BLOCK_SIZE = 100000
+ETH_MINIMAL_SUB_TASK_TX_COUNT = 100
