@@ -47,6 +47,8 @@ GATEWAY_TRANSACTION_STATS_INTERVAL_S = 1 * 60
 GATEWAY_TRANSACTION_STATS_LOOKBACK = 1
 GATEWAY_BDN_PERFORMANCE_STATS_INTERVAL_S = 15 * 60
 GATEWAY_BDN_PERFORMANCE_STATS_LOOKBACK = 1
+GATEWAY_TRANSACTION_FEED_STATS_INTERVAL_S = 5 * 60
+GATEWAY_TRANSACTION_FEED_STATS_LOOKBACK = 1
 
 ETH_GATEWAY_STATS_INTERVAL = 60
 ETH_GATEWAY_STATS_LOOKBACK = 1
@@ -101,3 +103,12 @@ TRACKED_BLOCK_MAX_HASH_LOOKUP = 100
 
 BDN_TX_PROCESSING_TIME_WARNING_THRESHOLD_S = 0.05
 BLOCKCHAIN_TX_PROCESSING_TIME_WARNING_THRESHOLD_S = 0.05
+
+WS_DEFAULT_PORT = 28333
+WS_DEFAULT_HOST = LOCALHOST
+RPC_SUBSCRIBER_MAX_QUEUE_SIZE = 500
+WS_MIN_RECONNECT_TIMEOUT_S = 1
+WS_RECONNECT_TIMEOUTS = [1, 2, 3, 5, 8, 13]
+
+PENDING_TX_FEED_CONSIDER_INACTIVE_INTERVAL_S = 60
+WS_PROVIDER_MAX_QUEUE_SIZE = 1000
